% Matlab script for plotting a 2D scatterplot exported by Sliver.
% The data is saved in the file "data.csv" which is read in here.
% Refer to the header lines in the data file for more information.
% This script can be customized to add other desired plot features.
%
% Plot properties can also be manually adjusted in Matlab after
% the figure is created through the Edit-->Figure Properties
% menu option.

figureleftmargin = 100;
figurebottommargin = 75;
figureheight = 600;
figurewidth = 1000;

cd(fileparts(which(mfilename)));
data = readtable('data.csv');
filename = data.Properties.VariableNames(4);
filename = strrep(filename,'ddott','.');
filename = strrep(filename,'_','\_');
pointsize = data{1,3};
linewidth = data{1,4};
plotoptions = data{1,5};
xaxis = char(data{1,1});
yaxis = char(data{1,2});
xaxis = strrep(xaxis,'_','\_');
yaxis = strrep(yaxis,'_','\_');
% The first two values in row 2 are interpreted as strings
% rather than doubles because those values in row 1 (the row
% after the header) are strings, so these need to be converted.
rvalue = str2double(data{2,1});
gvalue = str2double(data{2,2});
bvalue = data{2,3};
lineRGBcolor = [rvalue gvalue bvalue];
filledflag = data{2,4};

% Remove the first 2 rows of the table, which are
% just passed parameters.
data(1,:) = [];
data(1,:) = [];

pointRGBcolor = data{:,[3 4 5]};

figure('Position',[figureleftmargin figurebottommargin figurewidth figureheight])
if plotoptions == 1
	% A scatterplot of points only.
	if filledflag == 1
		scatter(str2double(data{:,1}),str2double(data{:,2}), ...
			pointsize,pointRGBcolor,'filled')
	else
		scatter(str2double(data{:,1}),str2double(data{:,2}), ...
			pointsize,pointRGBcolor)	
	end
elseif plotoptions == 2
	% A line plot.
	plot(str2double(data{:,1}),str2double(data{:,2}), ...
		'Color',lineRGBcolor,'LineWidth',linewidth)
elseif plotoptions == 3
	% A scatterplot and line plot combined.
	% Plot the points on top of the line.
	hold on;
	plot(str2double(data{:,1}),str2double(data{:,2}), ...
		'Color',lineRGBcolor,'LineWidth',linewidth)
	if filledflag == 1
		scatter(str2double(data{:,1}),str2double(data{:,2}), ...
			pointsize,pointRGBcolor,'filled')
	else
		scatter(str2double(data{:,1}),str2double(data{:,2}), ...
			pointsize,pointRGBcolor)	
	end
	hold off;
end
% Show major grid lines.
grid on
% Show minor grid lines (commented out by default)
% grid minor
title(filename);
xlabel(xaxis);
ylabel(yaxis);
